## -----------------------------------------------------------------------------
library(readxl)
library(dplyr)
library(netmeta)


## -----------------------------------------------------------------------------
settings.meta(digits = 2)


## -----------------------------------------------------------------------------
AcuteMania = read_excel("AcuteMania.xls")
AcuteMania = as.data.frame(AcuteMania)
str(AcuteMania)




## -----------------------------------------------------------------------------
table(AcuteMania$treatment)


## -----------------------------------------------------------------------------
table(table(AcuteMania$studyid))


## -----------------------------------------------------------------------------
AcuteManiaPair = pairwise(treat = treatment, event = r, n = n,
  data = AcuteMania, studlab = studyid, sm = "OR")


## -----------------------------------------------------------------------------
subset(AcuteMania, studyid < 4)
subset(AcuteManiaPair, studyid < 4) %>% select(1:9)


## -----------------------------------------------------------------------------
net1 = netmeta(AcuteManiaPair)


## -----------------------------------------------------------------------------
netgraph(net1)


## -----------------------------------------------------------------------------
netgraph(net1, plastic = FALSE, col = 1, multiarm = FALSE, points = TRUE,
  cex.points = table(AcuteMania$treatment))


## ---- eval = FALSE------------------------------------------------------------
## # install.packages("rgl")
## # netgraph(net1, dim = "3d", col = 1)


## -----------------------------------------------------------------------------
net1 = netmeta(AcuteManiaPair, ref = "PLA", common = FALSE)
net1


## -----------------------------------------------------------------------------
net1.pla = netmeta(AcuteManiaPair, ref = "PLA", common = FALSE,
  baseline.reference = FALSE)
net1.pla


## -----------------------------------------------------------------------------
round(net1$tau, 3)


## -----------------------------------------------------------------------------
paste0(round(100 * net1$I2), "%")


## -----------------------------------------------------------------------------
leaguetable = netleague(net1)
leaguetable


## -----------------------------------------------------------------------------
write.csv(leaguetable$random, "leaguetable-random.csv",
  row.names = FALSE)


## ---- eval = FALSE------------------------------------------------------------
## # netleague(net1, digits = 2, path = "leaguetable-random.xlsx")


## ---- fig.width=6, fig.height=5-----------------------------------------------
forest(net1)


## ---- fig.width=6, fig.height=5-----------------------------------------------
forest(net1, ref = "HAL")


## ---- fig.width=6, fig.height=5-----------------------------------------------
forest(net1, sortvar = TE)


## ---- fig.width=6, fig.height=5-----------------------------------------------
forest(net1, sortvar = TE,
  leftcols = c("studlab", "k"),
  leftlabs = c("Drug", "Direct\nstudies"),
  xlab = "Response to treatment",
  smlab = "NMA random effects")


## -----------------------------------------------------------------------------
netrank(net1, small = "bad")


## ---- fig.width=6, fig.height=5-----------------------------------------------
forest(net1,
  rightcols = c("effect", "ci", "Pscore"),
  rightlabs = "P-Score", sortvar = -Pscore, small = "bad",
  xlab = "Response to treatment",
  smlab = "Active drug vs placebo")


## -----------------------------------------------------------------------------
table(AcuteManiaPair$rob)


## -----------------------------------------------------------------------------
net2 = netmeta(AcuteManiaPair, ref = "PLA", common = FALSE,
  subset = rob == 1)
net2


## -----------------------------------------------------------------------------
net1$d


## -----------------------------------------------------------------------------
net1$designs


## -----------------------------------------------------------------------------
split1 = netsplit(net1) 
print(split1, show = "both", digits = 2)


## -----------------------------------------------------------------------------
decomp.design(net1)




